==> selenium-devtools-v117-4.13.0-sources.jar: org/openqa/selenium/devtools/v117/storage/model/InterestGroupDetails.java <==
package org.openqa.selenium.devtools.v117.storage.model;

import org.openqa.selenium.Beta;
import org.openqa.selenium.json.JsonInput;

/**
 * The full details of an interest group.
 */
public class InterestGroupDetails {

    private final java.lang.String ownerOrigin;

    private final java.lang.String name;

    private final org.openqa.selenium.devtools.v117.network.model.TimeSinceEpoch expirationTime;

    private final java.lang.String joiningOrigin;

    private final java.util.Optional<java.lang.String> biddingUrl;

    private final java.util.Optional<java.lang.String> biddingWasmHelperUrl;

    private final java.util.Optional<java.lang.String> updateUrl;

    private final java.util.Optional<java.lang.String> trustedBiddingSignalsUrl;

    private final java.util.List<java.lang.String> trustedBiddingSignalsKeys;

    private final java.util.Optional<java.lang.String> userBiddingSignals;

    private final java.util.List<org.openqa.selenium.devtools.v117.storage.model.InterestGroupAd> ads;

    private final java.util.List<org.openqa.selenium.devtools.v117.storage.model.InterestGroupAd> adComponents;

    public InterestGroupDetails(java.lang.String ownerOrigin, java.lang.String name, org.openqa.selenium.devtools.v117.network.model.TimeSinceEpoch expirationTime, java.lang.String joiningOrigin, java.util.Optional<java.lang.String> biddingUrl, java.util.Optional<java.lang.String> biddingWasmHelperUrl, java.util.Optional<java.lang.String> updateUrl, java.util.Optional<java.lang.String> trustedBiddingSignalsUrl, java.util.List<java.lang.String> trustedBiddingSignalsKeys, java.util.Optional<java.lang.String> userBiddingSignals, java.util.List<org.openqa.selenium.devtools.v117.storage.model.InterestGroupAd> ads, java.util.List<org.openqa.selenium.devtools.v117.storage.model.InterestGroupAd> adComponents) {
        this.ownerOrigin = java.util.Objects.requireNonNull(ownerOrigin, "ownerOrigin is required");
        this.name = java.util.Objects.requireNonNull(name, "name is required");
        this.expirationTime = java.util.Objects.requireNonNull(expirationTime, "expirationTime is required");
        this.joiningOrigin = java.util.Objects.requireNonNull(joiningOrigin, "joiningOrigin is required");
        this.biddingUrl = biddingUrl;
        this.biddingWasmHelperUrl = biddingWasmHelperUrl;
        this.updateUrl = updateUrl;
        this.trustedBiddingSignalsUrl = trustedBiddingSignalsUrl;
        this.trustedBiddingSignalsKeys = java.util.Objects.requireNonNull(trustedBiddingSignalsKeys, "trustedBiddingSignalsKeys is required");
        this.userBiddingSignals = userBiddingSignals;
        this.ads = java.util.Objects.requireNonNull(ads, "ads is required");
        this.adComponents = java.util.Objects.requireNonNull(adComponents, "adComponents is required");
    }

    public java.lang.String getOwnerOrigin() {
        return ownerOrigin;
    }

    public java.lang.String getName() {
        return name;
    }

    public org.openqa.selenium.devtools.v117.network.model.TimeSinceEpoch getExpirationTime() {
        return expirationTime;
    }

    public java.lang.String getJoiningOrigin() {
        return joiningOrigin;
    }

    public java.util.Optional<java.lang.String> getBiddingUrl() {
        return biddingUrl;
    }

    public java.util.Optional<java.lang.String> getBiddingWasmHelperUrl() {
        return biddingWasmHelperUrl;
    }

    public java.util.Optional<java.lang.String> getUpdateUrl() {
        return updateUrl;
    }

    public java.util.Optional<java.lang.String> getTrustedBiddingSignalsUrl() {
        return trustedBiddingSignalsUrl;
    }

    public java.util.List<java.lang.String> getTrustedBiddingSignalsKeys() {
        return trustedBiddingSignalsKeys;
    }

    public java.util.Optional<java.lang.String> getUserBiddingSignals() {
        return userBiddingSignals;
    }

    public java.util.List<org.openqa.selenium.devtools.v117.storage.model.InterestGroupAd> getAds() {
        return ads;
    }

    public java.util.List<org.openqa.selenium.devtools.v117.storage.model.InterestGroupAd> getAdComponents() {
        return adComponents;
    }

    private static InterestGroupDetails fromJson(JsonInput input) {
        java.lang.String ownerOrigin = null;
        java.lang.String name = null;
        org.openqa.selenium.devtools.v117.network.model.TimeSinceEpoch expirationTime = null;
        java.lang.String joiningOrigin = null;
        java.util.Optional<java.lang.String> biddingUrl = java.util.Optional.empty();
        java.util.Optional<java.lang.String> biddingWasmHelperUrl = java.util.Optional.empty();
        java.util.Optional<java.lang.String> updateUrl = java.util.Optional.empty();
        java.util.Optional<java.lang.String> trustedBiddingSignalsUrl = java.util.Optional.empty();
        java.util.List<java.lang.String> trustedBiddingSignalsKeys = null;
        java.util.Optional<java.lang.String> userBiddingSignals = java.util.Optional.empty();
        java.util.List<org.openqa.selenium.devtools.v117.storage.model.InterestGroupAd> ads = null;
        java.util.List<org.openqa.selenium.devtools.v117.storage.model.InterestGroupAd> adComponents = null;
        input.beginObject();
        while (input.hasNext()) {
            switch(input.nextName()) {
                case "ownerOrigin":
                    ownerOrigin = input.nextString();
                    break;
                case "name":
                    name = input.nextString();
                    break;
                case "expirationTime":
                    expirationTime = input.read(org.openqa.selenium.devtools.v117.network.model.TimeSinceEpoch.class);
                    break;
                case "joiningOrigin":
                    joiningOrigin = input.nextString();
                    break;
                case "biddingUrl":
                    biddingUrl = java.util.Optional.ofNullable(input.nextString());
                    break;
                case "biddingWasmHelperUrl":
                    biddingWasmHelperUrl = java.util.Optional.ofNullable(input.nextString());
                    break;
                case "updateUrl":
                    updateUrl = java.util.Optional.ofNullable(input.nextString());
                    break;
                case "trustedBiddingSignalsUrl":
                    trustedBiddingSignalsUrl = java.util.Optional.ofNullable(input.nextString());
                    break;
                case "trustedBiddingSignalsKeys":
                    trustedBiddingSignalsKeys = input.read(new com.google.common.reflect.TypeToken<java.util.List<java.lang.String>>() {
                    }.getType());
                    break;
                case "userBiddingSignals":
                    userBiddingSignals = java.util.Optional.ofNullable(input.nextString());
                    break;
                case "ads":
                    ads = input.read(new com.google.common.reflect.TypeToken<java.util.List<org.openqa.selenium.devtools.v117.storage.model.InterestGroupAd>>() {
                    }.getType());
                    break;
                case "adComponents":
                    adComponents = input.read(new com.google.common.reflect.TypeToken<java.util.List<org.openqa.selenium.devtools.v117.storage.model.InterestGroupAd>>() {
                    }.getType());
                    break;
                default:
                    input.skipValue();
                    break;
            }
        }
        input.endObject();
        return new InterestGroupDetails(ownerOrigin, name, expirationTime, joiningOrigin, biddingUrl, biddingWasmHelperUrl, updateUrl, trustedBiddingSignalsUrl, trustedBiddingSignalsKeys, userBiddingSignals, ads, adComponents);
    }
}

==> selenium-devtools-v117-4.15.0-sources.jar: org/openqa/selenium/devtools/v117/storage/model/InterestGroupDetails.java <==
package org.openqa.selenium.devtools.v117.storage.model;

import org.openqa.selenium.Beta;
import org.openqa.selenium.json.JsonInput;

/**
 * The full details of an interest group.
 */
public class InterestGroupDetails {

    private final java.lang.String ownerOrigin;

    private final java.lang.String name;

    private final org.openqa.selenium.devtools.v117.network.model.TimeSinceEpoch expirationTime;

    private final java.lang.String joiningOrigin;

    private final java.util.Optional<java.lang.String> biddingUrl;

    private final java.util.Optional<java.lang.String> biddingWasmHelperUrl;

    private final java.util.Optional<java.lang.String> updateUrl;

    private final java.util.Optional<java.lang.String> trustedBiddingSignalsUrl;

    private final java.util.List<java.lang.String> trustedBiddingSignalsKeys;

    private final java.util.Optional<java.lang.String> userBiddingSignals;

    private final java.util.List<org.openqa.selenium.devtools.v117.storage.model.InterestGroupAd> ads;

    private final java.util.List<org.openqa.selenium.devtools.v117.storage.model.InterestGroupAd> adComponents;

    public InterestGroupDetails(java.lang.String ownerOrigin, java.lang.String name, org.openqa.selenium.devtools.v117.network.model.TimeSinceEpoch expirationTime, java.lang.String joiningOrigin, java.util.Optional<java.lang.String> biddingUrl, java.util.Optional<java.lang.String> biddingWasmHelperUrl, java.util.Optional<java.lang.String> updateUrl, java.util.Optional<java.lang.String> trustedBiddingSignalsUrl, java.util.List<java.lang.String> trustedBiddingSignalsKeys, java.util.Optional<java.lang.String> userBiddingSignals, java.util.List<org.openqa.selenium.devtools.v117.storage.model.InterestGroupAd> ads, java.util.List<org.openqa.selenium.devtools.v117.storage.model.InterestGroupAd> adComponents) {
        this.ownerOrigin = java.util.Objects.requireNonNull(ownerOrigin, "ownerOrigin is required");
        this.name = java.util.Objects.requireNonNull(name, "name is required");
        this.expirationTime = java.util.Objects.requireNonNull(expirationTime, "expirationTime is required");
        this.joiningOrigin = java.util.Objects.requireNonNull(joiningOrigin, "joiningOrigin is required");
        this.biddingUrl = biddingUrl;
        this.biddingWasmHelperUrl = biddingWasmHelperUrl;
        this.updateUrl = updateUrl;
        this.trustedBiddingSignalsUrl = trustedBiddingSignalsUrl;
        this.trustedBiddingSignalsKeys = java.util.Objects.requireNonNull(trustedBiddingSignalsKeys, "trustedBiddingSignalsKeys is required");
        this.userBiddingSignals = userBiddingSignals;
        this.ads = java.util.Objects.requireNonNull(ads, "ads is required");
        this.adComponents = java.util.Objects.requireNonNull(adComponents, "adComponents is required");
    }

    public java.lang.String getOwnerOrigin() {
        return ownerOrigin;
    }

    public java.lang.String getName() {
        return name;
    }

    public org.openqa.selenium.devtools.v117.network.model.TimeSinceEpoch getExpirationTime() {
        return expirationTime;
    }

    public java.lang.String getJoiningOrigin() {
        return joiningOrigin;
    }

    public java.util.Optional<java.lang.String> getBiddingUrl() {
        return biddingUrl;
    }

    public java.util.Optional<java.lang.String> getBiddingWasmHelperUrl() {
        return biddingWasmHelperUrl;
    }

    public java.util.Optional<java.lang.String> getUpdateUrl() {
        return updateUrl;
    }

    public java.util.Optional<java.lang.String> getTrustedBiddingSignalsUrl() {
        return trustedBiddingSignalsUrl;
    }

    public java.util.List<java.lang.String> getTrustedBiddingSignalsKeys() {
        return trustedBiddingSignalsKeys;
    }

    public java.util.Optional<java.lang.String> getUserBiddingSignals() {
        return userBiddingSignals;
    }

    public java.util.List<org.openqa.selenium.devtools.v117.storage.model.InterestGroupAd> getAds() {
        return ads;
    }

    public java.util.List<org.openqa.selenium.devtools.v117.storage.model.InterestGroupAd> getAdComponents() {
        return adComponents;
    }

    private static InterestGroupDetails fromJson(JsonInput input) {
        java.lang.String ownerOrigin = null;
        java.lang.String name = null;
        org.openqa.selenium.devtools.v117.network.model.TimeSinceEpoch expirationTime = null;
        java.lang.String joiningOrigin = null;
        java.util.Optional<java.lang.String> biddingUrl = java.util.Optional.empty();
        java.util.Optional<java.lang.String> biddingWasmHelperUrl = java.util.Optional.empty();
        java.util.Optional<java.lang.String> updateUrl = java.util.Optional.empty();
        java.util.Optional<java.lang.String> trustedBiddingSignalsUrl = java.util.Optional.empty();
        java.util.List<java.lang.String> trustedBiddingSignalsKeys = null;
        java.util.Optional<java.lang.String> userBiddingSignals = java.util.Optional.empty();
        java.util.List<org.openqa.selenium.devtools.v117.storage.model.InterestGroupAd> ads = null;
        java.util.List<org.openqa.selenium.devtools.v117.storage.model.InterestGroupAd> adComponents = null;
        input.beginObject();
        while (input.hasNext()) {
            switch(input.nextName()) {
                case "ownerOrigin":
                    ownerOrigin = input.nextString();
                    break;
                case "name":
                    name = input.nextString();
                    break;
                case "expirationTime":
                    expirationTime = input.read(org.openqa.selenium.devtools.v117.network.model.TimeSinceEpoch.class);
                    break;
                case "joiningOrigin":
                    joiningOrigin = input.nextString();
                    break;
                case "biddingUrl":
                    biddingUrl = java.util.Optional.ofNullable(input.nextString());
                    break;
                case "biddingWasmHelperUrl":
                    biddingWasmHelperUrl = java.util.Optional.ofNullable(input.nextString());
                    break;
                case "updateUrl":
                    updateUrl = java.util.Optional.ofNullable(input.nextString());
                    break;
                case "trustedBiddingSignalsUrl":
                    trustedBiddingSignalsUrl = java.util.Optional.ofNullable(input.nextString());
                    break;
                case "trustedBiddingSignalsKeys":
                    trustedBiddingSignalsKeys = input.readArray(java.lang.String.class);
                    break;
                case "userBiddingSignals":
                    userBiddingSignals = java.util.Optional.ofNullable(input.nextString());
                    break;
                case "ads":
                    ads = input.readArray(org.openqa.selenium.devtools.v117.storage.model.InterestGroupAd.class);
                    break;
                case "adComponents":
                    adComponents = input.readArray(org.openqa.selenium.devtools.v117.storage.model.InterestGroupAd.class);
                    break;
                default:
                    input.skipValue();
                    break;
            }
        }
        input.endObject();
        return new InterestGroupDetails(ownerOrigin, name, expirationTime, joiningOrigin, biddingUrl, biddingWasmHelperUrl, updateUrl, trustedBiddingSignalsUrl, trustedBiddingSignalsKeys, userBiddingSignals, ads, adComponents);
    }
}
